@@ -12,6 +12,7 @@
 #  License for the specific language governing permissions and limitations
 #  under the License.
 
+from oslo_log import versionutils
 import pecan
 from six.moves.urllib import parse
 
@@ -30,6 +31,9 @@ from barbican.tasks import certificate_resources as cert_resources
 
 LOG = utils.getLogger(__name__)
 
+_DEPRECATION_MSG = u._LW('%s has been deprecated in the Newton release. It '
+                         'will be removed in the Pike release.')
+
 
 def _certificate_authority_not_found():
     """Throw exception indicating certificate authority not found."""
@@ -67,6 +71,8 @@ class CertificateAuthorityController(controllers.ACLMixin):
 
     def __init__(self, ca):
         LOG.debug('=== Creating CertificateAuthorityController ===')
+        msg = _DEPRECATION_MSG % "Certificate Authorities API"
+        versionutils.report_deprecated_feature(LOG, msg)
         self.ca = ca
         self.ca_repo = repo.get_ca_repository()
         self.project_ca_repo = repo.get_project_ca_repository()
@@ -256,6 +262,8 @@ class CertificateAuthoritiesController(controllers.ACLMixin):
 
     def __init__(self):
         LOG.debug('Creating CertificateAuthoritiesController')
+        msg = _DEPRECATION_MSG % "Certificate Authorities API"
+        versionutils.report_deprecated_feature(LOG, msg)
         self.ca_repo = repo.get_ca_repository()
         self.project_ca_repo = repo.get_project_ca_repository()
         self.preferred_ca_repo = repo.get_preferred_ca_repository()
@@ -439,7 +447,8 @@ class CertificateAuthoritiesController(controllers.ACLMixin):
     @controllers.handle_exceptions(u._('Retrieve project preferred CA'))
     @controllers.enforce_rbac('certificate_authorities:get_preferred_ca')
     def preferred(self, external_project_id, **kw):
-        LOG.debug('Start certificate_authorities get project preferred CA')
+        LOG.debug('Start certificate_authorities get'
+                  ' project preferred CA')
 
         project = res.get_or_create_project(external_project_id)
 
@@ -457,7 +466,8 @@ class CertificateAuthoritiesController(controllers.ACLMixin):
     @controllers.enforce_rbac('certificate_authorities:post')
     @controllers.enforce_content_types(['application/json'])
     def on_post(self, external_project_id, **kwargs):
-        LOG.debug('Start on_post for project-ID %s:...', external_project_id)
+        LOG.debug('Start on_post for project-ID %s:...',
+                  external_project_id)
 
         data = api.load_body(pecan.request, validator=self.validator)
         project = res.get_or_create_project(external_project_id)
