@@ -39,6 +39,11 @@ def _consumer_ownership_mismatch():
                          'can delete it.'))
 
 
+def _invalid_consumer_id():
+    """Throw exception indicating consumer id is invalid."""
+    pecan.abort(404, u._('Not Found. Provided consumer id is invalid.'))
+
+
 class ContainerConsumerController(controllers.ACLMixin):
     """Handles Consumer entity retrieval and deletion requests."""
 
@@ -78,12 +83,15 @@ class ContainerConsumersController(controllers.ACLMixin):
         self.container_id = container_id
         self.consumer_repo = repo.get_container_consumer_repository()
         self.container_repo = repo.get_container_repository()
+        self.project_repo = repo.get_project_repository()
         self.validator = validators.ContainerConsumerValidator()
         self.quota_enforcer = quota.QuotaEnforcer('consumers',
                                                   self.consumer_repo)
 
     @pecan.expose()
     def _lookup(self, consumer_id, *remainder):
+        if not utils.validate_id_is_uuid(consumer_id):
+            _invalid_consumer_id()()
         return ContainerConsumerController(consumer_id), remainder
 
     @pecan.expose(generic=True)
@@ -94,13 +102,12 @@ class ContainerConsumersController(controllers.ACLMixin):
     @controllers.handle_exceptions(u._('ContainerConsumers(s) retrieval'))
     @controllers.enforce_rbac('consumers:get')
     def on_get(self, external_project_id, **kw):
-        LOG.debug(u._('Start consumers on_get '
-                      'for container-ID %s:'), self.container_id)
-
+        LOG.debug('Start consumers on_get '
+                  'for container-ID %s:', self.container_id)
         result = self.consumer_repo.get_by_container_id(
             self.container_id,
             offset_arg=kw.get('offset', 0),
-            limit_arg=kw.get('limit', None),
+            limit_arg=kw.get('limit'),
             suppress_exception=True
         )
 
@@ -113,8 +120,11 @@ class ContainerConsumersController(controllers.ACLMixin):
                 hrefs.convert_to_hrefs(c.to_dict_fields())
                 for c in consumers
             ]
+            consumer_path = "containers/{container_id}/consumers".format(
+                container_id=self.container_id)
+
             resp_ctrs_overall = hrefs.add_nav_hrefs(
-                'consumers',
+                consumer_path,
                 offset,
                 limit,
                 total,
@@ -160,6 +170,11 @@ class ContainerConsumersController(controllers.ACLMixin):
     def on_delete(self, external_project_id, **kwargs):
         data = api.load_body(pecan.request, validator=self.validator)
         LOG.debug('Start on_delete...%s', data)
+        project = self.project_repo.find_by_external_project_id(
+            external_project_id, suppress_exception=True)
+        if not project:
+            _consumer_not_found()
+
         consumer = self.consumer_repo.get_by_values(
             self.container_id,
             data["name"],
@@ -171,7 +186,7 @@ class ContainerConsumersController(controllers.ACLMixin):
         LOG.debug("Found consumer: %s", consumer)
 
         container = self._get_container(self.container_id)
-        owner_of_consumer = consumer.project_id == external_project_id
+        owner_of_consumer = consumer.project_id == project.id
         owner_of_container = container.project.external_id \
             == external_project_id
         if not owner_of_consumer and not owner_of_container:
