@@ -12,8 +12,6 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-import uuid
-
 import webob.exc
 
 from barbican.api import middleware as mw
@@ -30,15 +28,17 @@ class BaseContextMiddleware(mw.Middleware):
     def process_request(self, req):
         request_id = req.headers.get('x-openstack-request-id')
         if not request_id:
-            request_id = b'req-' + str(uuid.uuid4()).encode('ascii')
+            request_id = b'req-' + utils.generate_uuid().encode('ascii')
         setattr(req, 'request_id', request_id)
 
     def process_response(self, resp):
 
         resp.headers['x-openstack-request-id'] = resp.request.request_id
 
-        LOG.info('%s: %s - %s %s', u._LI('Processed request'),
-                 resp.status, resp.request.method, resp.request.url)
+        LOG.info(u._LI('Processed request: %(status)s - %(method)s %(url)s'),
+                 {"status": resp.status,
+                  "method": resp.request.method,
+                  "url": resp.request.url})
         return resp
 
 
@@ -62,8 +62,6 @@ class ContextMiddleware(BaseContextMiddleware):
 
         if req.headers.get('X-Identity-Status') == 'Confirmed':
             req.context = self._get_authenticated_context(req)
-            LOG.debug("==== Inserted barbican auth "
-                      "request context: %s ====", req.context.to_dict())
         elif CONF.allow_anonymous_access:
             req.context = self._get_anonymous_context()
             LOG.debug("==== Inserted barbican unauth "
