@@ -22,7 +22,6 @@
 from __future__ import print_function
 
 import argparse
-import six
 import sys
 
 from oslo_config import cfg
@@ -171,7 +170,7 @@ class HSMCommands(object):
         self.pkcs11.generate_key(int(length), self.session, str(label),
                                  encrypt=True, wrap=True, master_key=True)
         self.pkcs11.return_session(self.session)
-        print ("MKEK successfully generated!")
+        print("MKEK successfully generated!")
 
     gen_hmac_description = "Generates a new HMAC key"
 
@@ -184,7 +183,7 @@ class HSMCommands(object):
     @args('--passphrase', metavar='<passphrase>', default=None, required=True,
           help='Password to login to PKCS11 session')
     @args('--label', '-L', metavar='<label>', default='primarymkek',
-          help='The label of the Matser HMAC Key')
+          help='The label of the Master HMAC Key')
     @args('--length', '-l', metavar='<length>', default=32,
           help='The length of the Master HMAC Key (default is 32)')
     def gen_hmac(self, passphrase, libpath=None, slotid=None, label=None,
@@ -194,7 +193,7 @@ class HSMCommands(object):
         self.pkcs11.generate_key(int(length), self.session, str(label),
                                  sign=True, master_key=True)
         self.pkcs11.return_session(self.session)
-        print ("HMAC successfully generated!")
+        print("HMAC successfully generated!")
 
     rewrap_pkek_description = "Re-wrap project MKEKs"
 
@@ -215,7 +214,7 @@ class HSMCommands(object):
     def _verify_label_does_not_exist(self, label, session):
         key_handle = self.pkcs11.get_key_handle(label, session)
         if key_handle:
-            print (
+            print(
                 "The label {label} already exists! "
                 "Please try again.".format(label=label)
             )
@@ -228,7 +227,7 @@ CATEGORIES = {
 }
 
 
-# Modifying similiar code from nova/cmd/manage.py
+# Modifying similar code from nova/cmd/manage.py
 def methods_of(obj):
     """Get all callable methods of an object that don't start with underscore
 
@@ -239,7 +238,7 @@ def methods_of(obj):
     for fn in dir(obj):
         if callable(getattr(obj, fn)) and not fn.startswith('_'):
             result.append((fn, getattr(obj, fn),
-                          getattr(obj, fn+'_description', None)))
+                          getattr(obj, fn + '_description', None)))
     return result
 
 
@@ -315,14 +314,13 @@ def main():
         v = getattr(CONF.category, 'action_kwarg_' + k)
         if v is None:
             continue
-        if isinstance(v, six.string_types):
+        if isinstance(v, bytes):
             v = v.decode('utf-8')
         fn_kwargs[k] = v
 
     # call the action with the remaining arguments
     try:
-        ret = fn(*fn_args, **fn_kwargs)
-        return(ret)
+        return fn(*fn_args, **fn_kwargs)
     except Exception as e:
         sys.exit("ERROR: %s" % e)
 
