@@ -22,6 +22,7 @@ import sys
 sys.path.insert(0, os.getcwd())
 
 from barbican.common import config
+from barbican import i18n as u
 from barbican.model import clean
 from barbican.model.migration import commands
 from oslo_log import log
@@ -163,7 +164,7 @@ class DatabaseManager(object):
         args.func(args)
 
 
-def _exception_is_successfull_exit(thrown_exception):
+def _exception_is_successful_exit(thrown_exception):
     return (isinstance(thrown_exception, SystemExit) and
             (thrown_exception.code is None or thrown_exception.code == 0))
 
@@ -174,8 +175,9 @@ def main():
         dm = DatabaseManager(CONF)
         dm.execute()
     except Exception as ex:
-        if not _exception_is_successfull_exit(ex):
-            LOG.exception('Problem seen trying to run barbican db manage')
+        if not _exception_is_successful_exit(ex):
+            LOG.exception(u._LE('Problem seen trying to run'
+                                ' barbican db manage'))
             sys.stderr.write("ERROR: {0}\n".format(ex))
             sys.exit(1)
 
