@@ -56,6 +56,11 @@ def convert_certificate_authority_to_href(ca_id):
     return convert_resource_id_to_href('cas', ca_id)
 
 
+def convert_secret_stores_to_href(secret_store_id):
+    """Convert the secret-store ID to a HATEOAS-style href."""
+    return convert_resource_id_to_href('secret-stores', secret_store_id)
+
+
 # TODO(hgedikli) handle list of fields in here
 def convert_to_hrefs(fields):
     """Convert id's within a fields dict to HATEOAS-style hrefs."""
@@ -150,11 +155,11 @@ def get_container_id_from_ref(container_ref):
 def get_secret_id_from_ref(secret_ref):
     """Parse a secret reference and return the secret ID
 
-    TODO(Dave) Implement this, or make one generic ID from REF function
-
     :param secret_ref: HTTP reference of secret
     :return: a string containing the ID of the secret
     """
+    secret_id = secret_ref.rsplit('/', 1)[1]
+    return secret_id
 
 
 def get_ca_id_from_ref(ca_ref):
