@@ -68,6 +68,8 @@ _SECRET_META_REPOSITORY = None
 _SECRET_USER_META_REPOSITORY = None
 _SECRET_REPOSITORY = None
 _TRANSPORT_KEY_REPOSITORY = None
+_SECRET_STORES_REPOSITORY = None
+_PROJECT_SECRET_STORE_REPOSITORY = None
 
 
 CONF = config.CONF
@@ -90,8 +92,7 @@ def hard_reset():
 def setup_database_engine_and_factory():
     global sa_logger, _SESSION_FACTORY, _ENGINE
 
-    LOG.info('Setting up database engine and session factory')
-    LOG.debug('Sql connection = %s', CONF.sql_connection)
+    LOG.info(u._LI('Setting up database engine and session factory'))
     if CONF.debug:
         sa_logger = logging.getLogger('sqlalchemy.engine')
         sa_logger.setLevel(logging.DEBUG)
@@ -105,6 +106,7 @@ def setup_database_engine_and_factory():
     # session instance per thread.
     session_maker = sa_orm.sessionmaker(bind=_ENGINE)
     _SESSION_FACTORY = sqlalchemy.orm.scoped_session(session_maker)
+    _initialize_secret_stores_data()
 
 
 def start():
@@ -203,6 +205,18 @@ def _get_engine(engine):
     return engine
 
 
+def _initialize_secret_stores_data():
+    """Initializes secret stores data in database.
+
+    This logic is executed only when database engine and factory is built.
+    Secret store get_manager internally reads secret store plugin configuration
+    from service configuration and saves it in secret_stores table in database.
+    """
+    if utils.is_multiple_backends_enabled():
+        from barbican.plugin.interface import secret_store
+        secret_store.get_manager()
+
+
 def is_db_connection_error(args):
     """Return True if error in connecting to db."""
     # NOTE(adam_g): This is currently MySQL specific and needs to be extended
@@ -215,7 +229,8 @@ def is_db_connection_error(args):
 
 
 def _create_engine(connection, **engine_args):
-    LOG.debug("Sql connection: %s; Args: %s", connection, engine_args)
+    LOG.debug('Sql connection: please check "sql_connection" property in '
+              'barbican configuration file; Args: %s', engine_args)
 
     engine = sqlalchemy.create_engine(connection, **engine_args)
 
@@ -295,9 +310,9 @@ def clean_paging_values(offset_arg=0, limit_arg=CONF.default_limit_paging):
     except ValueError:
         limit = CONF.default_limit_paging
 
-    LOG.debug("Clean paging values limit=%s, offset=%s",
-              limit, offset
-              )
+    LOG.debug("Clean paging values limit=%(limit)s, offset=%(offset)s" %
+              {'limit': limit,
+               'offset': offset})
 
     return offset, limit
 
@@ -599,17 +614,19 @@ class ProjectRepo(BaseRepo):
 class SecretRepo(BaseRepo):
     """Repository for the Secret entity."""
 
-    def get_by_create_date(self, external_project_id, offset_arg=None,
-                           limit_arg=None, name=None, alg=None, mode=None,
-                           bits=0, secret_type=None, suppress_exception=False,
-                           session=None, acl_only=None, user_id=None):
+    def get_secret_list(self, external_project_id,
+                        offset_arg=None, limit_arg=None,
+                        name=None, alg=None, mode=None,
+                        bits=0, secret_type=None, suppress_exception=False,
+                        session=None, acl_only=None, user_id=None,
+                        created=None, updated=None, expiration=None,
+                        sort=None):
         """Returns a list of secrets
 
-        The returned secrets are ordered by the date they were created at
-        and paged based on the offset and limit fields. The external_project_id
-        is external-to-Barbican value assigned to the project by Keystone.
+        The list is scoped to secrets that are associated with the
+        external_project_id (e.g. Keystone Project ID), and filtered
+        using any provided filters.
         """
-
         offset, limit = clean_paging_values(offset_arg, limit_arg)
 
         session = self.get_session(session)
@@ -631,6 +648,19 @@ class SecretRepo(BaseRepo):
             query = query.filter(models.Secret.bit_length == bits)
         if secret_type:
             query = query.filter(models.Secret.secret_type == secret_type)
+        if created:
+            query = self._build_date_filter_query(query, 'created_at', created)
+        if updated:
+            query = self._build_date_filter_query(query, 'updated_at', updated)
+        if expiration:
+            query = self._build_date_filter_query(
+                query, 'expiration', expiration
+            )
+        else:
+            query = query.filter(or_(models.Secret.expiration.is_(None),
+                                     models.Secret.expiration > utcnow))
+        if sort:
+            query = self._build_sort_filter_query(query, sort)
 
         if acl_only and acl_only.lower() == 'true' and user_id:
             query = query.join(models.SecretACL)
@@ -685,11 +715,74 @@ class SecretRepo(BaseRepo):
         :param project_id: id of barbican project entity
         :param session: existing db session reference.
         """
+
+        utcnow = timeutils.utcnow()
+        expiration_filter = or_(models.Secret.expiration.is_(None),
+                                models.Secret.expiration > utcnow)
+
         query = session.query(models.Secret).filter_by(deleted=False)
         query = query.filter(models.Secret.project_id == project_id)
+        query = query.filter(expiration_filter)
 
         return query
 
+    def _build_date_filter_query(self, query, attribute, date_filters):
+        """Parses date_filters to apply each filter to the given query
+
+        :param query: query object to apply filters to
+        :param attribute: name of the model attribute to be filtered
+        :param date_filters: comma separated string of date filters to apply
+        """
+        parse = timeutils.parse_isotime
+        for filter in date_filters.split(','):
+            if filter.startswith('lte:'):
+                isotime = filter[4:]
+                query = query.filter(or_(
+                    getattr(models.Secret, attribute) < parse(isotime),
+                    getattr(models.Secret, attribute) == parse(isotime))
+                )
+            elif filter.startswith('lt:'):
+                isotime = filter[3:]
+                query = query.filter(
+                    getattr(models.Secret, attribute) < parse(isotime)
+                )
+            elif filter.startswith('gte:'):
+                isotime = filter[4:]
+                query = query.filter(or_(
+                    getattr(models.Secret, attribute) > parse(isotime),
+                    getattr(models.Secret, attribute) == parse(isotime))
+                )
+            elif filter.startswith('gt:'):
+                isotime = filter[3:]
+                query = query.filter(
+                    getattr(models.Secret, attribute) > parse(isotime)
+                )
+            else:
+                query = query.filter(
+                    getattr(models.Secret, attribute) == parse(filter)
+                )
+        return query
+
+    def _build_sort_filter_query(self, query, sort_filters):
+        """Parses sort_filters to order the query"""
+        key_to_column_map = {
+            'created': 'created_at',
+            'updated': 'updated_at'
+        }
+        ordering = list()
+        for sort in sort_filters.split(','):
+            if ':' in sort:
+                key, direction = sort.split(':')
+            else:
+                key, direction = sort, 'asc'
+            ordering.append(
+                getattr(
+                    getattr(models.Secret, key_to_column_map.get(key, key)),
+                    direction
+                )()
+            )
+        return query.order_by(*ordering)
+
     def get_secret_by_id(self, entity_id, suppress_exception=False,
                          session=None):
         """Gets secret by its entity id without project id check."""
@@ -741,7 +834,7 @@ class SecretStoreMetadatumRepo(BaseRepo):
     """
 
     def save(self, metadata, secret_model):
-        """Saves the the specified metadata for the secret.
+        """Saves the specified metadata for the secret.
 
         :raises NotFound if entity does not exist.
         """
@@ -788,7 +881,7 @@ class SecretUserMetadatumRepo(BaseRepo):
     """
 
     def create_replace_user_metadata(self, secret_id, metadata):
-        """Creates or replaces the the specified metadata for the secret."""
+        """Creates or replaces the specified metadata for the secret."""
         now = timeutils.utcnow()
 
         session = get_session()
@@ -1005,7 +1098,7 @@ class OrderPluginMetadatumRepo(BaseRepo):
     """
 
     def save(self, metadata, order_model):
-        """Saves the the specified metadata for the order.
+        """Saves the specified metadata for the order.
 
         :raises NotFound if entity does not exist.
         """
@@ -1058,7 +1151,7 @@ class OrderBarbicanMetadatumRepo(BaseRepo):
     """
 
     def save(self, metadata, order_model):
-        """Saves the the specified metadata for the order.
+        """Saves the specified metadata for the order.
 
         :raises NotFound if entity does not exist.
         """
@@ -1341,9 +1434,9 @@ class ContainerConsumerRepo(BaseRepo):
             session.rollback()  # We know consumer already exists.
 
             # This operation is idempotent, so log this and move on
-            LOG.debug("Consumer %s already exists for container %s,"
-                      " continuing...", (new_consumer.name, new_consumer.URL),
-                      new_consumer.container_id)
+            LOG.debug("Consumer %s with URL %s already exists for "
+                      "container %s, continuing...", new_consumer.name,
+                      new_consumer.URL, new_consumer.container_id)
             # Get the existing entry and reuse it by clearing the deleted flags
             existing_consumer = self.get_by_values(
                 new_consumer.container_id, new_consumer.name, new_consumer.URL,
@@ -1593,7 +1686,7 @@ class CertificateAuthorityMetadatumRepo(BaseRepo):
     """
 
     def save(self, metadata, ca_model):
-        """Saves the the specified metadata for the CA.
+        """Saves the specified metadata for the CA.
 
         :raises NotFound if entity does not exist.
         """
@@ -1623,7 +1716,7 @@ class CertificateAuthorityMetadatumRepo(BaseRepo):
         except sa_orm.exc.NoResultFound:
             metadata = dict()
 
-        return dict((m.key, m.value) for m in metadata)
+        return {(m.key, m.value) for m in metadata}
 
     def _do_entity_name(self):
         """Sub-class hook: return entity name, such as for debugging."""
@@ -2111,6 +2204,153 @@ class ProjectQuotasRepo(BaseRepo):
         entity.delete(session=session)
 
 
+class SecretStoresRepo(BaseRepo):
+    """Repository for the SecretStores entity.
+
+    SecretStores entries are not soft delete. So there is no
+    need to have deleted=False filter in queries.
+    """
+
+    def get_all(self, session=None):
+        """Get list of available secret stores.
+
+        Status value is not used while getting complete list as
+        we will just maintain ACTIVE ones. No other state is used and
+        needed here.
+        :param session: SQLAlchemy session object.
+        :return: None
+        """
+        session = self.get_session(session)
+        query = session.query(models.SecretStores)
+        query.order_by(models.SecretStores.created_at.asc())
+        return query.all()
+
+    def _do_entity_name(self):
+        """Sub-class hook: return entity name, such as for debugging."""
+        return "SecretStores"
+
+    def _do_build_get_query(self, entity_id, external_project_id, session):
+        """Sub-class hook: build a retrieve query."""
+        return session.query(models.SecretStores).filter_by(
+            id=entity_id)
+
+    def _do_validate(self, values):
+        """Sub-class hook: validate values."""
+        pass
+
+
+class ProjectSecretStoreRepo(BaseRepo):
+    """Repository for the ProjectSecretStore entity.
+
+    ProjectSecretStore entries are not soft delete. So there is no
+    need to have deleted=False filter in queries.
+    """
+
+    def get_secret_store_for_project(self, project_id, external_project_id,
+                                     suppress_exception=False, session=None):
+        """Returns preferred secret store for a project if set.
+
+        :param project_id: ID of project whose preferred secret store is set
+        :param external_project_id: external ID of project whose preferred
+               secret store is set
+        :param suppress_exception: when True, NotFound is not raised
+        :param session: SQLAlchemy session object.
+
+        Will return preferred secret store by external project id if provided
+        otherwise uses barbican project identifier to lookup.
+
+        Throws exception in case no preferred secret store is defined and
+        supporess_exception=False. If suppress_exception is True, then returns
+        None for no preferred secret store for a project found.
+        """
+        session = self.get_session(session)
+        if external_project_id is None:
+            query = session.query(models.ProjectSecretStore).filter_by(
+                project_id=project_id)
+        else:
+            query = session.query(models.ProjectSecretStore)
+            query = query.join(models.Project,
+                               models.ProjectSecretStore.project)
+            query = query.filter(models.Project.external_id ==
+                                 external_project_id)
+        try:
+            entity = query.one()
+        except sa_orm.exc.NoResultFound:
+            LOG.info(u._LE("No preferred secret store found for project = %s"),
+                     project_id)
+            entity = None
+            if not suppress_exception:
+                _raise_entity_not_found(self._do_entity_name(), project_id)
+        return entity
+
+    def create_or_update_for_project(self, project_id, secret_store_id,
+                                     session=None):
+        """Create or update preferred secret store for a project.
+
+        :param project_id: ID of project whose preferred secret store is set
+        :param secret_store_id: ID of secret store
+        :param session: SQLAlchemy session object.
+        :return: None
+
+        If preferred secret store is not set for given project, then create
+        new preferred secret store setting for that project. If secret store
+        setting for project is already there, then it updates with given secret
+        store id.
+        """
+        session = self.get_session(session)
+        try:
+            entity = self.get_secret_store_for_project(project_id, None,
+                                                       session=session)
+        except exception.NotFound:
+            entity = self.create_from(
+                models.ProjectSecretStore(project_id, secret_store_id),
+                session=session)
+        else:
+            entity.secret_store_id = secret_store_id
+            entity.save(session)
+        return entity
+
+    def get_count_by_secret_store(self, secret_store_id, session=None):
+        """Gets count of projects mapped to a given secret store.
+
+        :param secret_store_id: id of secret stores entity
+        :param session: existing db session reference. If None, gets session.
+        :return: an number 0 or greater
+
+        This method is supposed to provide count of projects which are
+        currently set to use input secret store as their preferred store. This
+        is used when existing secret store configuration is removed and
+        validation is done to make sure that there are no projects using it as
+        preferred secret store.
+        """
+        session = self.get_session(session)
+        query = session.query(models.ProjectSecretStore).filter_by(
+            secret_store_id=secret_store_id)
+        return query.count()
+
+    def _do_entity_name(self):
+        """Sub-class hook: return entity name, such as for debugging."""
+        return "ProjectSecretStore"
+
+    def _do_build_get_query(self, entity_id, external_project_id, session):
+        """Sub-class hook: build a retrieve query."""
+        return session.query(models.ProjectSecretStore).filter_by(
+            id=entity_id)
+
+    def _do_validate(self, values):
+        """Sub-class hook: validate values."""
+        pass
+
+    def _build_get_project_entities_query(self, project_id, session):
+        """Builds query for getting preferred secret stores list for a project.
+
+        :param project_id: id of barbican project entity
+        :param session: existing db session reference.
+        """
+        return session.query(models.ProjectSecretStore).filter_by(
+            project_id=project_id)
+
+
 def get_ca_repository():
     """Returns a singleton Secret repository instance."""
     global _CA_REPOSITORY
@@ -2238,6 +2478,19 @@ def get_transport_key_repository():
     return _get_repository(_TRANSPORT_KEY_REPOSITORY, TransportKeyRepo)
 
 
+def get_secret_stores_repository():
+    """Returns a singleton Secret Stores repository instance."""
+    global _SECRET_STORES_REPOSITORY
+    return _get_repository(_SECRET_STORES_REPOSITORY, SecretStoresRepo)
+
+
+def get_project_secret_store_repository():
+    """Returns a singleton Project Secret Store repository instance."""
+    global _PROJECT_SECRET_STORE_REPOSITORY
+    return _get_repository(_PROJECT_SECRET_STORE_REPOSITORY,
+                           ProjectSecretStoreRepo)
+
+
 def _get_repository(global_ref, repo_class):
     if not global_ref:
         global_ref = repo_class()
