@@ -20,19 +20,24 @@ from oslo_config import cfg
 import six
 
 from barbican.common import config
+from barbican.common import utils
 from barbican import i18n as u
-from barbican.plugin.crypto import crypto as c
+from barbican.plugin.crypto import base as c
 
 
 CONF = config.new_config()
+LOG = utils.getLogger(__name__)
 
 simple_crypto_plugin_group = cfg.OptGroup(name='simple_crypto_plugin',
                                           title="Simple Crypto Plugin Options")
 simple_crypto_plugin_opts = [
     cfg.StrOpt('kek',
-               default=b'dGhpcnR5X3R3b19ieXRlX2tleWJsYWhibGFoYmxhaGg=',
+               default='dGhpcnR5X3R3b19ieXRlX2tleWJsYWhibGFoYmxhaGg=',
                help=u._('Key encryption key to be used by Simple Crypto '
-                        'Plugin'))
+                        'Plugin'), secret=True),
+    cfg.StrOpt('plugin_name',
+               help=u._('User friendly plugin name'),
+               default='Software Only Crypto'),
 ]
 CONF.register_group(simple_crypto_plugin_group)
 CONF.register_opts(simple_crypto_plugin_opts, group=simple_crypto_plugin_group)
@@ -44,6 +49,14 @@ class SimpleCryptoPlugin(c.CryptoPluginBase):
 
     def __init__(self, conf=CONF):
         self.master_kek = conf.simple_crypto_plugin.kek
+        self.plugin_name = conf.simple_crypto_plugin.plugin_name
+        LOG.warning(u._LW("This plugin is NOT meant for a production "
+                          "environment. This is meant just for development "
+                          "and testing purposes. Please use another plugin "
+                          "for production."))
+
+    def get_plugin_name(self):
+        return self.plugin_name
 
     def _get_kek(self, kek_meta_dto):
         if not kek_meta_dto.plugin_meta:
@@ -107,11 +120,11 @@ class SimpleCryptoPlugin(c.CryptoPluginBase):
         - DSA, with passphrase (not supported)
 
         Note: PyCrypto is not capable of serializing DSA
-        keys and DER formated keys. Such keys will be
+        keys and DER formatted keys. Such keys will be
         serialized to Base64 PEM to store in DB.
 
         TODO (atiwari/reaperhulk): PyCrypto is not capable to serialize
-        DSA keys and DER formated keys, later we need to pick better
+        DSA keys and DER formatted keys, later we need to pick better
         crypto lib.
         """
         if(generate_dto.algorithm is None or generate_dto
