@@ -28,7 +28,6 @@ except ImportError:
 
 from oslo_service import service
 
-from barbican.common import config
 from barbican.common import utils
 from barbican import i18n as u
 from barbican.model import models
@@ -42,8 +41,6 @@ if newrelic_loaded:
 
 LOG = utils.getLogger(__name__)
 
-CONF = config.CONF
-
 
 # Maps the common/shared RetryTasks (returned from lower-level business logic
 # and plugin processing) to top-level RPC tasks in the Tasks class below.
