@@ -13,11 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import base64
 import datetime
 import six
 import unittest
 
+from oslo_serialization import base64
 import testtools
 
 from barbican.common import exception as excep
@@ -47,7 +47,7 @@ def get_private_key_req():
             'algorithm': 'rsa',
             'bit_length': 2048,
             'secret_type': 'private',
-            'payload': base64.b64encode(keys.get_private_key_pem())}
+            'payload': base64.encode_as_text(keys.get_private_key_pem())}
 
 
 def get_public_key_req():
@@ -57,7 +57,7 @@ def get_public_key_req():
             'algorithm': 'rsa',
             'bit_length': 2048,
             'secret_type': 'public',
-            'payload': base64.b64encode(keys.get_public_key_pem())}
+            'payload': base64.encode_as_text(keys.get_public_key_pem())}
 
 
 def get_certificate_req():
@@ -67,7 +67,7 @@ def get_certificate_req():
             'algorithm': 'rsa',
             'bit_length': 2048,
             'secret_type': 'certificate',
-            'payload': base64.b64encode(keys.get_certificate_pem())}
+            'payload': base64.encode_as_text(keys.get_certificate_pem())}
 
 
 def get_passphrase_req():
@@ -104,7 +104,7 @@ class WhenTestingValidatorsFunctions(utils.BaseTestCase):
 
     def test_secret_too_big_is_true_for_big_unicode_secrets(self):
         beer = u'\U0001F37A'
-        data = beer * (validators.CONF.max_allowed_secret_in_bytes / 4)
+        data = beer * (validators.CONF.max_allowed_secret_in_bytes // 4)
         data += u'1'
 
         is_too_big = validators.secret_too_big(data)
@@ -119,7 +119,7 @@ class WhenTestingSecretValidator(utils.BaseTestCase):
         super(WhenTestingSecretValidator, self).setUp()
 
         self.name = 'name'
-        self.payload = b'not-encrypted'
+        self.payload = 'not-encrypted'
         self.payload_content_type = 'text/plain'
         self.secret_algorithm = 'algo'
         self.secret_bit_length = 512
@@ -212,7 +212,7 @@ class WhenTestingSecretValidator(utils.BaseTestCase):
         result = self.validator.validate(self.secret_req)
 
         self.assertIn('expiration', result)
-        self.assertTrue(not result['expiration'])
+        self.assertFalse(result['expiration'])
 
     def test_should_raise_numeric_name(self):
         self.secret_req['name'] = 123
@@ -415,9 +415,8 @@ class WhenTestingSecretValidator(utils.BaseTestCase):
         try:
             self.validator.validate(self.secret_req)
         except excep.InvalidObject as e:
-            self.assertNotEqual(str(e), 'None')
+            self.assertIsNotNone(e)
             self.assertIsNotNone(e.message)
-            self.assertNotEqual(e.message, 'None')
         else:
             self.fail('No validation exception was raised')
 
@@ -516,7 +515,7 @@ class WhenTestingSecretValidator(utils.BaseTestCase):
     def test_validation_should_raise_with_unicode_payload(self):
         self.secret_req['payload_content_type'] = 'application/octet-stream'
         self.secret_req['payload_content_encoding'] = 'base64'
-        self.secret_req['payload'] = unichr(0x0080)
+        self.secret_req['payload'] = six.unichr(0x0080)
 
         exception = self.assertRaises(
             excep.InvalidObject,
@@ -664,14 +663,13 @@ class WhenTestingContainerValidator(utils.BaseTestCase):
     def test_should_raise_no_type(self):
         del self.container_req['type']
 
-        self.assertRaises(
+        exception = self.assertRaises(
             excep.InvalidObject,
             self.validator.validate,
             self.container_req,
         )
 
-        # TODO(hgedikli): figure out why invalid_property is null here
-        # self.assertEqual('type', e.exception.invalid_property)
+        self.assertIn('type', exception.message)
 
     def test_should_raise_empty_type(self):
         self.container_req['type'] = ''
@@ -833,6 +831,26 @@ class WhenTestingContainerValidator(utils.BaseTestCase):
             container_req,
         )
 
+    def test_ensure_secret_ref_starts_with_request_hostname(self):
+        # Attempt to add some bogus secret refs.
+        secret_refs = [
+            {
+                'name': 'pass_malicious_hostname',
+                'secret_ref': 'http://www.malicious.com:8080/spoofForToken?'
+                'dummy=http://localhost:9311'
+            },
+        ]
+        container_req = {
+            'name': 'test-container',
+            'type': 'generic',
+            'secret_refs': secret_refs
+        }
+        self.assertRaises(
+            excep.UnsupportedField,
+            self.validator.validate,
+            container_req,
+        )
+
 
 class WhenTestingRSAContainerValidator(utils.BaseTestCase):
 
@@ -1196,7 +1214,7 @@ class WhenTestingKeyTypeOrderValidator(utils.BaseTestCase):
     def test_should_pass_good_exp_meta_in_order_refs(self):
         self.key_order_req['meta']['algorithm'] = 'AES'
         ony_year_factor = datetime.timedelta(days=1 * 365)
-        date_after_year = datetime.datetime.now() + ony_year_factor
+        date_after_year = datetime.datetime.utcnow() + ony_year_factor
         date_after_year_str = date_after_year.strftime('%Y-%m-%d %H:%M:%S')
         self.key_order_req['meta']['expiration'] = date_after_year_str
         result = self.validator.validate(self.key_order_req)
@@ -1356,8 +1374,9 @@ class WhenTestingSimpleCMCOrderValidator(utils.BaseTestCase):
     def setUp(self):
         super(WhenTestingSimpleCMCOrderValidator, self).setUp()
         self.type = 'certificate'
+        request_data = base64.encode_as_text(certs.create_good_csr())
         self.meta = {'request_type': 'simple-cmc',
-                     'request_data': base64.b64encode(certs.create_good_csr()),
+                     'request_data': request_data,
                      'requestor_name': 'Barbican User',
                      'requestor_email': 'barbican_user@example.com',
                      'requestor_phone': '555-1212'}
@@ -1399,14 +1418,15 @@ class WhenTestingSimpleCMCOrderValidator(utils.BaseTestCase):
                           self.order_req)
 
     def test_should_raise_with_bad_pkcs10_data(self):
-        self.meta['request_data'] = base64.b64encode(certs.create_bad_csr())
+        request_data = base64.encode_as_text(certs.create_bad_csr())
+        self.meta['request_data'] = request_data
         self._set_order()
         self.assertRaises(excep.InvalidPKCS10Data,
                           self.validator.validate,
                           self.order_req)
 
     def test_should_raise_with_signed_wrong_key_pkcs10_data(self):
-        self.meta['request_data'] = base64.b64encode(
+        self.meta['request_data'] = base64.encode_as_text(
             certs.create_csr_signed_with_wrong_key())
         self._set_order()
         self.assertRaises(excep.InvalidPKCS10Data,
@@ -1414,7 +1434,7 @@ class WhenTestingSimpleCMCOrderValidator(utils.BaseTestCase):
                           self.order_req)
 
     def test_should_raise_with_unsigned_pkcs10_data(self):
-        self.meta['request_data'] = base64.b64encode(
+        self.meta['request_data'] = base64.encode_as_text(
             certs.create_csr_that_has_not_been_signed())
         self._set_order()
         self.assertRaises(excep.InvalidPKCS10Data,
