@@ -23,7 +23,7 @@ import mock
 import six
 
 from barbican.model import models
-from barbican.plugin.crypto import crypto as plugin
+from barbican.plugin.crypto import base as plugin
 from barbican.plugin.crypto import simple_crypto as simple
 from barbican.tests import utils
 
@@ -73,7 +73,7 @@ class WhenTestingSimpleCryptoPlugin(utils.BaseTestCase):
         kek_meta_dto = self._get_mocked_kek_meta_dto()
         kek_meta_dto.plugin_meta = UENC_project_kek
 
-        unencrypted = 'PlainTextSecret'
+        unencrypted = b'PlainTextSecret'
         encrypt_dto = plugin.EncryptDTO(unencrypted)
         response_dto = self.plugin.encrypt(encrypt_dto,
                                            kek_meta_dto,
@@ -356,3 +356,6 @@ class WhenTestingSimpleCryptoPlugin(utils.BaseTestCase):
                                   response_dto.kek_meta_extended,
                                   mock.MagicMock())
         self.assertEqual(16, len(key))
+
+    def test_get_plugin_name(self):
+        self.assertIsNotNone(self.plugin.get_plugin_name())
