@@ -30,6 +30,10 @@ from functionaltests.common import config
 
 CONF = config.get_config()
 
+conf_host_href_used = CONF.keymanager.server_host_href_set
+conf_multiple_backends_enabled = CONF.keymanager.\
+    server_multiple_backends_enabled
+
 
 class TestCase(oslotest.BaseTestCase):
     max_payload_size = 10000
@@ -124,7 +128,7 @@ class PagingTestCase(TestCase):
         detect duplicates across multiple calls)
         """
         self.assertIsNotNone(resources)
-        self.assertEqual(len(resources), expected_size)
+        self.assertEqual(expected_size, len(resources))
         self.assertEqual(next_ref_should_be_none, next_ref is None)
         self.assertEqual(prev_ref_should_be_none, prev_ref is None)
 
@@ -135,7 +139,7 @@ class PagingTestCase(TestCase):
         if len(self._all_fetched_resources):
             duplicates = [entity for entity in resources if entity in
                           self._all_fetched_resources]
-            self.assertEqual(len(duplicates), 0)
+            self.assertEqual(0, len(duplicates))
 
         # add to our running list of resource refs
         self._all_fetched_resources.extend(resources)
@@ -389,3 +393,28 @@ class PagingTestCase(TestCase):
                                       prev_ref=prev_ref, expected_size=10,
                                       next_ref_should_be_none=False,
                                       prev_ref_should_be_none=True)
+
+    @testcase.attr('positive')
+    def test_paging_with_default_limit_and_large_offsets(self):
+        """Covers resource paging limit and offset attributes."""
+        test_model = self.create_model()
+
+        number_of_resources = 25
+
+        # create a number of resources
+        filter = self._set_filter_field(test_model)
+        self.create_resources(count=number_of_resources, model=test_model)
+
+        large_offset = 265613988875874769338781322035779626829233452653394495
+        limit = 10
+
+        # pass in non-integer values for limit and offset
+        resp, resources, next_ref, prev_ref = self.get_resources(
+            limit=limit,
+            offset=large_offset, filter=filter)
+
+        self.assertEqual(200, resp.status_code)
+        self._validate_resource_group(resources=resources, next_ref=next_ref,
+                                      prev_ref=prev_ref, expected_size=10,
+                                      next_ref_should_be_none=False,
+                                      prev_ref_should_be_none=True)
