@@ -17,16 +17,25 @@ import base64
 import binascii
 import json
 import sys
+import testtools
 import time
 
 from testtools import testcase
 
+from barbican.plugin.interface import secret_store as ss
 from barbican.plugin.util import translations
 from barbican.tests import keys
 from barbican.tests import utils
 from functionaltests.api import base
 from functionaltests.api.v1.behaviors import secret_behaviors
+from functionaltests.api.v1.behaviors import secretstores_behaviors
 from functionaltests.api.v1.models import secret_models
+from functionaltests.common import config
+
+
+CONF = config.get_config()
+admin_a = CONF.rbac_users.admin_a
+admin_b = CONF.rbac_users.admin_b
 
 
 def get_pem_content(pem):
@@ -135,6 +144,10 @@ class SecretsTestCase(base.TestCase):
         self.behaviors.delete_all_created_secrets()
         super(SecretsTestCase, self).tearDown()
 
+    def _cleanup_all_secrets(self):
+        for user_name in self.client.get_all_functional_test_user_names():
+            self.behaviors.delete_all_secrets_for_user(user_name=user_name)
+
     @testcase.attr('negative')
     def test_secret_create_with_only_content_type_no_payload(self):
         """Create secret with valid content type but no payload."""
@@ -144,7 +157,7 @@ class SecretsTestCase(base.TestCase):
         test_model.payload_content_type = 'application/octet-stream'
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
 
     @testcase.attr('positive')
     def test_secret_create_then_check_content_types(self):
@@ -153,10 +166,10 @@ class SecretsTestCase(base.TestCase):
             **self.default_secret_create_data)
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         resp = self.behaviors.get_secret_metadata(secret_ref)
-        self.assertEqual(resp.status_code, 200)
+        self.assertEqual(200, resp.status_code)
         content_types = resp.model.content_types
         self.assertIsNotNone(content_types)
         self.assertIn('default', content_types)
@@ -170,7 +183,7 @@ class SecretsTestCase(base.TestCase):
             **self.default_secret_create_all_none_data)
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
     @testcase.attr('negative')
     def test_secret_get_secret_doesnt_exist(self):
@@ -179,7 +192,22 @@ class SecretsTestCase(base.TestCase):
         Should return a 404.
         """
         resp = self.behaviors.get_secret_metadata('not_a_uuid')
-        self.assertEqual(resp.status_code, 404)
+        self.assertEqual(404, resp.status_code)
+
+    @testcase.attr('negative')
+    def test_secret_get_secret_payload_doesnt_exist(self):
+        """GET a non-existent payload.
+
+        Should return a 404.
+        """
+        test_model = secret_models.SecretModel(
+            **self.default_secret_create_all_none_data)
+
+        resp, secret_ref = self.behaviors.create_secret(test_model)
+        self.assertEqual(201, resp.status_code)
+
+        resp = self.behaviors.get_secret(secret_ref, 'text/plain')
+        self.assertEqual(404, resp.status_code)
 
     @testcase.attr('positive')
     def test_secret_get_payload_no_accept_header(self):
@@ -191,13 +219,13 @@ class SecretsTestCase(base.TestCase):
             **self.default_secret_create_data)
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         get_resp = self.behaviors.get_secret(
             secret_ref,
             payload_content_type='',
             omit_headers=['Accept'])
-        self.assertEqual(get_resp.status_code, 200)
+        self.assertEqual(200, get_resp.status_code)
         self.assertIn(test_model.payload,
                       binascii.b2a_base64(get_resp.content))
 
@@ -208,7 +236,7 @@ class SecretsTestCase(base.TestCase):
         Should return a 404.
         """
         resp = self.behaviors.delete_secret('not_a_uuid', expected_fail=True)
-        self.assertEqual(resp.status_code, 404)
+        self.assertEqual(404, resp.status_code)
 
     @testcase.attr('negative')
     def test_secret_get_invalid_mime_type(self):
@@ -219,7 +247,7 @@ class SecretsTestCase(base.TestCase):
         resp, secret_ref = self.behaviors.create_secret(test_model)
         resp = self.behaviors.get_secret(secret_ref,
                                          payload_content_type="i/m")
-        self.assertEqual(resp.status_code, 406)
+        self.assertEqual(406, resp.status_code)
 
     @testcase.attr('negative')
     def test_secret_create_with_expiration_passed(self):
@@ -232,7 +260,7 @@ class SecretsTestCase(base.TestCase):
         test_model.expiration = '2000-01-10T14:58:52.546795'
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
 
     @testcase.attr('negative')
     def test_secret_create_with_empty_strings(self):
@@ -244,7 +272,7 @@ class SecretsTestCase(base.TestCase):
             **self.default_secret_create_emptystrings_data)
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
 
     @testcase.attr('negative')
     def test_secret_create_with_invalid_content_type(self):
@@ -258,7 +286,7 @@ class SecretsTestCase(base.TestCase):
         headers = {"Content-Type": "crypto/boom"}
 
         resp, secret_ref = self.behaviors.create_secret(test_model, headers)
-        self.assertEqual(resp.status_code, 415)
+        self.assertEqual(415, resp.status_code)
 
     @testcase.attr('negative')
     def test_secret_create_with_oversized_payload(self):
@@ -272,7 +300,7 @@ class SecretsTestCase(base.TestCase):
         test_model.payload = str(self.oversized_payload)
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 413)
+        self.assertEqual(413, resp.status_code)
 
     @testcase.attr('negative')
     def test_secret_put_when_payload_doesnt_exist(self):
@@ -286,7 +314,7 @@ class SecretsTestCase(base.TestCase):
             payload_content_encoding='base64',
             payload='testing putting to non-existent secret')
 
-        self.assertEqual(resp.status_code, 404)
+        self.assertEqual(404, resp.status_code)
 
     @testcase.attr('negative')
     def test_secret_put_when_payload_already_exists(self):
@@ -298,14 +326,14 @@ class SecretsTestCase(base.TestCase):
             **self.default_secret_create_data)
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         resp = self.behaviors.update_secret_payload(
             secret_ref=secret_ref,
             payload_content_type='application/octet-stream',
             payload_content_encoding='base64',
             payload='testing putting data in secret that already has data')
-        self.assertEqual(resp.status_code, 409)
+        self.assertEqual(409, resp.status_code)
 
     @testcase.attr('negative')
     def test_secret_put_two_phase_empty_payload(self):
@@ -317,14 +345,14 @@ class SecretsTestCase(base.TestCase):
             **self.default_secret_create_two_phase_data)
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         put_resp = self.behaviors.update_secret_payload(
             secret_ref=secret_ref,
             payload_content_type='application/octet-stream',
             payload_content_encoding='base64',
             payload='')
-        self.assertEqual(put_resp.status_code, 400)
+        self.assertEqual(400, put_resp.status_code)
 
     @testcase.attr('negative')
     def test_secret_put_two_phase_invalid_content_type(self):
@@ -337,14 +365,14 @@ class SecretsTestCase(base.TestCase):
             **self.default_secret_create_two_phase_data)
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         put_resp = self.behaviors.update_secret_payload(
             secret_ref=secret_ref,
             payload_content_type='crypto/boom',
             payload_content_encoding='base64',
             payload='invalid content type')
-        self.assertEqual(put_resp.status_code, 415)
+        self.assertEqual(415, put_resp.status_code)
 
     @testcase.attr('negative')
     def test_secret_put_two_phase_no_payload(self):
@@ -356,14 +384,14 @@ class SecretsTestCase(base.TestCase):
             **self.default_secret_create_two_phase_data)
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         put_resp = self.behaviors.update_secret_payload(
             secret_ref=secret_ref,
             payload_content_type='application/octet-stream',
             payload_content_encoding='base64',
             payload=None)
-        self.assertEqual(put_resp.status_code, 400)
+        self.assertEqual(400, put_resp.status_code)
 
     @testcase.attr('negative')
     def test_secret_put_two_phase_w_oversized_binary_data_not_utf8(self):
@@ -381,14 +409,14 @@ class SecretsTestCase(base.TestCase):
             **self.default_secret_create_two_phase_data)
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         put_resp = self.behaviors.update_secret_payload(
             secret_ref=secret_ref,
             payload_content_type='application/octet-stream',
             payload_content_encoding='base64',
             payload=str(oversized_payload))
-        self.assertEqual(put_resp.status_code, 413)
+        self.assertEqual(413, put_resp.status_code)
 
     @testcase.attr('negative')
     def test_secret_put_two_phase_oversized_payload(self):
@@ -403,14 +431,14 @@ class SecretsTestCase(base.TestCase):
             **self.default_secret_create_two_phase_data)
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         put_resp = self.behaviors.update_secret_payload(
             secret_ref=secret_ref,
             payload_content_type='application/octet-stream',
             payload_content_encoding='base64',
             payload=oversized_payload)
-        self.assertEqual(put_resp.status_code, 413)
+        self.assertEqual(413, put_resp.status_code)
 
     @testcase.attr('positive')
     def test_secret_put_two_phase_valid_binary_data_not_utf8(self):
@@ -425,14 +453,14 @@ class SecretsTestCase(base.TestCase):
             **self.default_secret_create_two_phase_data)
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         put_resp = self.behaviors.update_secret_payload(
             secret_ref=secret_ref,
             payload_content_type='application/octet-stream',
             payload_content_encoding='base64',
             payload=str(data))
-        self.assertEqual(put_resp.status_code, 204)
+        self.assertEqual(204, put_resp.status_code)
 
     @testcase.attr('positive')
     def test_secret_put_two_phase_high_range_unicode_character(self):
@@ -446,14 +474,14 @@ class SecretsTestCase(base.TestCase):
             **self.default_secret_create_two_phase_data)
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         put_resp = self.behaviors.update_secret_payload(
             secret_ref=secret_ref,
             payload_content_type='application/octet-stream',
             payload_content_encoding='base64',
             payload=data)
-        self.assertEqual(put_resp.status_code, 204)
+        self.assertEqual(204, put_resp.status_code)
 
     @testcase.attr('positive')
     def test_secret_get_nones_payload_with_a_octet_stream(self):
@@ -465,13 +493,13 @@ class SecretsTestCase(base.TestCase):
         test_model.payload = base64.b64encode('abcdef')
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         get_resp = self.behaviors.get_secret(
             secret_ref,
             payload_content_type=test_model.payload_content_type,
             payload_content_encoding=test_model.payload_content_encoding)
-        self.assertEqual(get_resp.status_code, 200)
+        self.assertEqual(200, get_resp.status_code)
         self.assertIn(test_model.payload,
                       binascii.b2a_base64(get_resp.content))
 
@@ -485,7 +513,7 @@ class SecretsTestCase(base.TestCase):
         resp, secret_ref = self.behaviors.create_secret(test_model)
 
         # first, ensure that the return code is 400
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
 
         resp_dict = json.loads(resp.content)
 
@@ -513,18 +541,18 @@ class SecretsTestCase(base.TestCase):
         test_model.expiration = timestamp
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         # now get the secret - will be still valid
         get_resp = self.behaviors.get_secret_metadata(secret_ref)
-        self.assertEqual(get_resp.status_code, 200)
+        self.assertEqual(200, get_resp.status_code)
 
         # now wait 10 seconds
         time.sleep(10)
 
         # now get the secret - should be invalid (expired)
         resp = self.behaviors.get_secret_metadata(secret_ref)
-        self.assertEqual(resp.status_code, 404)
+        self.assertEqual(404, resp.status_code)
 
     @utils.parameterized_dataset({
         'alphanumeric': ['1f34ds'],
@@ -542,7 +570,7 @@ class SecretsTestCase(base.TestCase):
         test_model.name = name
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
     @utils.parameterized_dataset({
         'int': [400]
@@ -558,9 +586,11 @@ class SecretsTestCase(base.TestCase):
         test_model.name = name
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
 
     @testcase.attr('positive', 'non-standard-algorithm')
+    @testtools.skipIf(utils.is_kmip_enabled(),
+                      "KMIP does not support invalid algorithms")
     def test_secret_create_valid_algorithms(self):
         """Creates secrets with various valid algorithms."""
         algorithm = 'invalid'
@@ -569,7 +599,7 @@ class SecretsTestCase(base.TestCase):
         test_model.algorithm = algorithm
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
     @utils.parameterized_dataset({
         'int': [400]
@@ -582,8 +612,10 @@ class SecretsTestCase(base.TestCase):
         test_model.algorithm = algorithm
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
 
+    @testtools.skipIf(utils.is_kmip_enabled(),
+                      "KMIP does not support non-standard bit lengths")
     @utils.parameterized_dataset({
         'sixteen': [16],
         'fifteen': [15],
@@ -600,13 +632,12 @@ class SecretsTestCase(base.TestCase):
         test_model.bit_length = bit_length
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
     @utils.parameterized_dataset({
         '128': [128],
         '192': [192],
-        '256': [256],
-        '512': [512]
+        '256': [256]
     })
     @testcase.attr('positive')
     def test_secret_create_with_valid_bit_length(self, bit_length):
@@ -623,7 +654,7 @@ class SecretsTestCase(base.TestCase):
         test_model.payload = secret64
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
     @utils.parameterized_dataset({
         'str_type': ['not-an-int'],
@@ -641,7 +672,7 @@ class SecretsTestCase(base.TestCase):
         test_model.bit_length = bit_length
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
 
     @utils.parameterized_dataset({
         'cbc': ['cbc'],
@@ -655,7 +686,7 @@ class SecretsTestCase(base.TestCase):
         test_model.mode = mode
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
     @utils.parameterized_dataset({
         'zero': [0],
@@ -670,7 +701,7 @@ class SecretsTestCase(base.TestCase):
         test_model.mode = mode
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
 
     @utils.parameterized_dataset({
         'text_content_type_none_encoding': {
@@ -699,13 +730,13 @@ class SecretsTestCase(base.TestCase):
         test_model.payload_content_encoding = payload_content_encoding
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         get_resp = self.behaviors.get_secret(
             secret_ref,
             payload_content_type=payload_content_type,
             payload_content_encoding=payload_content_encoding)
-        self.assertEqual(get_resp.status_code, 200)
+        self.assertEqual(200, get_resp.status_code)
 
         if payload_content_encoding == 'base64':
             self.assertIn(test_model.payload,
@@ -740,13 +771,13 @@ class SecretsTestCase(base.TestCase):
         test_model.payload_content_encoding = payload_content_encoding
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         get_resp = self.behaviors.get_secret_based_on_content_type(
             secret_ref,
             payload_content_type=payload_content_type,
             payload_content_encoding=payload_content_encoding)
-        self.assertEqual(get_resp.status_code, 200)
+        self.assertEqual(200, get_resp.status_code)
 
         if payload_content_encoding == 'base64':
             self.assertIn(test_model.payload,
@@ -833,7 +864,7 @@ class SecretsTestCase(base.TestCase):
         test_model.payload_content_encoding = payload_content_encoding
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
 
     @utils.parameterized_dataset({
         'max_payload_string': [base.TestCase.max_sized_payload]
@@ -847,7 +878,7 @@ class SecretsTestCase(base.TestCase):
         test_model.override_values(**overrides)
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
     @utils.parameterized_dataset({
         'empty': [''],
@@ -868,7 +899,7 @@ class SecretsTestCase(base.TestCase):
         test_model.override_values(**overrides)
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
 
     @utils.parameterized_dataset({
         'negative_five_long_expire': {
@@ -898,7 +929,7 @@ class SecretsTestCase(base.TestCase):
         test_model.expiration = timestamp
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
     @utils.parameterized_dataset({
         'malformed_timezone': {
@@ -916,10 +947,12 @@ class SecretsTestCase(base.TestCase):
         test_model.expiration = timestamp
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
 
+    @testcase.skipIf(not base.conf_host_href_used, 'response href using '
+                     'wsgi request instead of CONF.host_href')
     @testcase.attr('positive')
-    def test_secret_create_change_host_header(self, **kwargs):
+    def test_secret_create_change_host_with_header_not_allowed(self, **kwargs):
         """Create a secret with a (possibly) malicious host name in header."""
 
         test_model = secret_models.SecretModel(
@@ -931,13 +964,38 @@ class SecretsTestCase(base.TestCase):
         resp, secret_ref = self.behaviors.create_secret(
             test_model, extra_headers=changed_host_header)
 
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         # get Location field from result and assert that it is NOT the
         # malicious one.
         regex = '.*{0}.*'.format(malicious_hostname)
         self.assertNotRegexpMatches(resp.headers['location'], regex)
 
+    @testcase.skipIf(base.conf_host_href_used, 'response href using '
+                     'CONF.host_href instead of wsgi request')
+    @testcase.attr('positive')
+    def test_secret_get_change_host_with_header_allowed(self, **kwargs):
+        """Get secret metadata with alternative proxy host name in header."""
+
+        test_model = secret_models.SecretModel(
+            **self.default_secret_create_data)
+
+        another_proxy_hostname = 'proxy2.server.com'
+        changed_host_header = {'Host': another_proxy_hostname}
+
+        # In test, cannot pass different host header during create as returned
+        # secret_ref in response contains that host in url. That url is used in
+        # deleting that secret during cleanup step
+        resp, secret_ref = self.behaviors.create_secret(
+            test_model)
+        self.assertEqual(201, resp.status_code)
+
+        resp = self.behaviors.get_secret_metadata(
+            secret_ref, extra_headers=changed_host_header)
+        # Check returned href has provided proxy hostname
+        regex = '.*{0}.*'.format(another_proxy_hostname)
+        self.assertRegexpMatches(resp.model.secret_ref, regex)
+
     @utils.parameterized_dataset({
         'symmetric': ['symmetric',
                       base64.b64decode(
@@ -1001,7 +1059,7 @@ class SecretsTestCase(base.TestCase):
         headers = {"Content-Type": http_content_type}
 
         resp, secret_ref = self.behaviors.create_secret(test_model, headers)
-        self.assertEqual(resp.status_code, 415)
+        self.assertEqual(415, resp.status_code)
 
     @utils.parameterized_dataset({
         'invalid_http_content_type_characaters_latin': {
@@ -1028,7 +1086,53 @@ class SecretsTestCase(base.TestCase):
         test_model.payload_content_type = payload_content_type
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
+
+
+@utils.parameterized_test_case
+class ListingSecretsTestCase(SecretsTestCase):
+
+    @utils.parameterized_dataset({
+        'query_by_name': {
+            'secret_1_dict': dict(name="name1"),
+            'secret_2_dict': dict(name="name2"),
+            'query_dict': dict(name="name1")
+        },
+        'query_by_algorithm': {
+            'secret_1_dict': dict(algorithm="algorithm1"),
+            'secret_2_dict': dict(algorithm="algorithm2"),
+            'query_dict': dict(alg="algorithm1")
+        },
+        'query_by_mode': {
+            'secret_1_dict': dict(mode="mode1"),
+            'secret_2_dict': dict(mode="mode2"),
+            'query_dict': dict(mode="mode1")
+        },
+        'query_by_bit_length': {
+            'secret_1_dict': dict(bit_length=1024),
+            'secret_2_dict': dict(bit_length=2048),
+            'query_dict': dict(bits=1024)
+        },
+        'query_by_secret_type': {
+            'secret_1_dict': dict(secret_type=ss.SecretType.SYMMETRIC),
+            'secret_2_dict': dict(secret_type=ss.SecretType.OPAQUE),
+            'query_dict': dict(secret_type=ss.SecretType.SYMMETRIC)
+        },
+    })
+    @testcase.attr('positive')
+    def test_secret_list_with_filter(self, secret_1_dict, secret_2_dict,
+                                     query_dict):
+        secret_1 = secret_models.SecretModel(**secret_1_dict)
+        secret_2 = secret_models.SecretModel(**secret_2_dict)
+
+        self.behaviors.create_secret(secret_1)
+        self.behaviors.create_secret(secret_2)
+
+        resp, secrets_list, next_ref, prev_ref = self.behaviors.get_secrets(
+            **query_dict)
+
+        self.assertEqual(200, resp.status_code)
+        self.assertEqual(1, len(secrets_list))
 
 
 class SecretsPagingTestCase(base.PagingTestCase):
@@ -1054,7 +1158,7 @@ class SecretsPagingTestCase(base.PagingTestCase):
 
     def get_resources(self, limit=10, offset=0, filter=None):
         return self.behaviors.get_secrets(limit=limit, offset=offset,
-                                          filter=filter)
+                                          name=filter)
 
     def set_filter_field(self, unique_str, model):
         '''Set the name field which we use in the get_resources '''
@@ -1390,3 +1494,120 @@ class SecretsUnauthedTestCase(base.TestCase):
             use_auth=False
         )
         self.assertEqual(401, resp.status_code)
+
+
+@utils.parameterized_test_case
+class SecretsMultipleBackendTestCase(base.TestCase):
+
+    def setUp(self):
+        super(SecretsMultipleBackendTestCase, self).setUp()
+        self.behaviors = secret_behaviors.SecretBehaviors(self.client)
+        self.ss_behaviors = secretstores_behaviors.SecretStoresBehaviors(
+            self.client)
+        self.default_secret_create_data = get_default_data()
+        if base.conf_multiple_backends_enabled:
+            resp, stores = self.ss_behaviors.get_all_secret_stores(
+                user_name=admin_a)
+            self.assertEqual(200, resp.status_code)
+            secret_store_ref = None
+            for store in stores['secret-stores']:
+                if not store['global_default']:
+                    secret_store_ref = store['secret_store_ref']
+                    break
+            # set preferred secret store for admin_a (project a) user
+            # and don't set preferred secret store for admin_b (project b) user
+            self.ss_behaviors.set_preferred_secret_store(secret_store_ref,
+                                                         user_name=admin_a)
+
+    def tearDown(self):
+        self.behaviors.delete_all_created_secrets()
+        if base.conf_multiple_backends_enabled:
+            self.ss_behaviors.cleanup_preferred_secret_store_entities()
+        super(SecretsMultipleBackendTestCase, self).tearDown()
+
+    @testcase.skipUnless(base.conf_multiple_backends_enabled, 'executed only '
+                         'when multiple backends support is enabled in '
+                         'barbican server side')
+    @utils.parameterized_dataset({
+        'symmetric_type_preferred_store': [
+            admin_a,
+            'symmetric',
+            base64.b64decode(get_default_payload()),
+            get_default_data()
+            ],
+        'private_type_preferred_store': [
+            admin_a,
+            'private',
+            keys.get_private_key_pem(),
+            get_private_key_req()
+            ],
+        'public_type_preferred_store': [
+            admin_a,
+            'public',
+            keys.get_public_key_pem(),
+            get_public_key_req()
+            ],
+        'certificate_type_preferred_store': [
+            admin_a,
+            'certificate',
+            keys.get_certificate_pem(),
+            get_certificate_req()
+            ],
+        'passphrase_type_preferred_store': [
+            admin_a,
+            'passphrase',
+            'mysecretpassphrase',
+            get_passphrase_req()
+            ],
+        'symmetric_type_no_preferred_store': [
+            admin_b,
+            'symmetric',
+            base64.b64decode(get_default_payload()),
+            get_default_data()
+            ],
+        'private_type_no_preferred_store': [
+            admin_b,
+            'private',
+            keys.get_private_key_pem(),
+            get_private_key_req()
+            ],
+        'public_type_no_preferred_store': [
+            admin_b,
+            'public',
+            keys.get_public_key_pem(),
+            get_public_key_req()
+            ],
+        'certificate_type_no_preferred_store': [
+            admin_b,
+            'certificate',
+            keys.get_certificate_pem(),
+            get_certificate_req()
+            ],
+        'passphrase_type_no_preferred_store': [
+            admin_b,
+            'passphrase',
+            'mysecretpassphrase',
+            get_passphrase_req()
+            ],
+    })
+    def test_secret_create_for(self, user_name, secret_type, expected, spec):
+        """Create secrets with various secret types with multiple backends."""
+        test_model = secret_models.SecretModel(**spec)
+        test_model.secret_type = secret_type
+
+        resp, secret_ref = self.behaviors.create_secret(test_model,
+                                                        user_name=user_name,
+                                                        admin=user_name)
+        self.assertEqual(201, resp.status_code)
+
+        resp = self.behaviors.get_secret_metadata(secret_ref,
+                                                  user_name=user_name)
+        secret_type_response = resp.model.secret_type
+        self.assertIsNotNone(secret_type_response)
+        self.assertEqual(secret_type, secret_type_response)
+
+        content_type = spec['payload_content_type']
+        get_resp = self.behaviors.get_secret(secret_ref,
+                                             content_type,
+                                             user_name=user_name)
+        self.assertEqual(expected, get_resp.content)
