@@ -35,6 +35,7 @@ def setup_config(config_file=''):
         cfg.StrOpt('region', default='RegionOne'),
         cfg.StrOpt('service_admin', default='service-admin'),
         cfg.StrOpt('service_admin_project', default='service'),
+        cfg.StrOpt('service_admin_domain', default='Default'),
         cfg.StrOpt('service_admin_password', default='secretservice',
                    secret=True)]
     TEST_CONF.register_group(identity_group)
@@ -44,10 +45,13 @@ def setup_config(config_file=''):
     rbac_users_options = [
         cfg.StrOpt('project_a', default='project_a'),
         cfg.StrOpt('project_b', default='project_b'),
+        cfg.StrOpt('project_domain', default='Default'),
         cfg.StrOpt('admin_a', default='project_a_admin'),
         cfg.StrOpt('admin_a_password', default='barbican', secret=True),
         cfg.StrOpt('creator_a', default='project_a_creator'),
         cfg.StrOpt('creator_a_password', default='barbican', secret=True),
+        cfg.StrOpt('creator_a_2', default='project_a_creator_2'),
+        cfg.StrOpt('creator_a_2_password', default='barbican', secret=True),
         cfg.StrOpt('observer_a', default='project_a_observer'),
         cfg.StrOpt('observer_a_password', default='barbican', secret=True),
         cfg.StrOpt('auditor_a', default='project_a_auditor'),
@@ -72,7 +76,10 @@ def setup_config(config_file=''):
         cfg.StrOpt('endpoint_type', default='public'),
         cfg.IntOpt('timeout', default=10),
         cfg.StrOpt('override_url', default=''),
-        cfg.StrOpt('override_url_version', default='')
+        cfg.StrOpt('override_url_version', default=''),
+        cfg.BoolOpt('verify_ssl', default=True),
+        cfg.BoolOpt('server_host_href_set', default=True),
+        cfg.BoolOpt('server_multiple_backends_enabled', default=False)
     ]
     TEST_CONF.register_group(keymanager_group)
     TEST_CONF.register_opts(keymanager_options, group=keymanager_group)
